Changelog
=========

0.7 (2016-05-14)
----------------

- Add writeFile(), appendToFile() and prependToFile().


0.6 (2015-11-22)
----------------

- Add insertAfterNthLine().


0.5 (1509201)
-----------

- Let addDirs() fail silently, if the directory to create, exists already.
- Better hlp-msgs.


0.4 (150920)
-----------

- Really adjust MANIFEST (good morning Kreuzberg)


0.3 (150920)
-----------

- Adjust MANIFEST


0.2 (150920)
-----------

- Add MANIFEST


0.1 (150920)
-----------

- Initial release

